@@ -27,12 +27,8 @@
 #include "gok-page-feedbacks.h"
 #include "gok-feedback.h"
 #include "gok-log.h"
-#include "support.h"
 #include "gok-settings-dialog.h"
 
-/* pointer to the settings dialog window */
-static GtkWidget* m_pWindowSettings;
-
 /* feedback that is currently displayed */
 static GokFeedback* m_pFeedbackCurrent;
 
@@ -55,14 +51,13 @@ static gboolean m_bIgnoreSoundNameChange;
 *
 * returns: TRUE if the page was properly initialized, FALSE if not.
 **/
-gboolean gok_page_feedbacks_initialize (GtkWidget* pWindowSettings)
+gboolean gok_page_feedbacks_initialize (GladeXML* xml)
 {
 	GtkWidget* pComboBox;
 	GokFeedback* pFeedback;
 	GList* items = NULL;
 	
-	g_assert (pWindowSettings != NULL);
-	m_pWindowSettings = pWindowSettings;
+	g_assert (xml != NULL);
 	m_pFeedbackCurrent = NULL;
 	m_bIgnoreChangeName = FALSE;
 	m_bChanged = TRUE;
@@ -72,7 +67,7 @@ gboolean gok_page_feedbacks_initialize (GtkWidget* pWindowSettings)
 	gok_feedbacks_update_sound_combo();
 	
 	/* add all the feedbacks to the combo box */
-	pComboBox = lookup_widget (gok_settingsdialog_get_window(), "comboFeedback");
+	pComboBox = glade_xml_get_widget (xml , "comboFeedback");
 	g_assert (pComboBox != NULL);
 
 	pFeedback = gok_feedback_get_first_feedback();
@@ -273,33 +268,38 @@ void gok_page_feedbacks_update_controls (GokFeedback* pFeedback)
 	/* if no feedback then disable all controls */
 	if (pFeedback == NULL)
 	{
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonChangeFeedbackName");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonChangeFeedbackName");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 			
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonDeleteFeedback");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonDeleteFeedback");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "checkKeyFlashing");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkKeyFlashing");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "spinKeyFlashing");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "spinKeyFlashing");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "checkSoundOn");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkSoundOn");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "comboSoundName");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "comboSoundName");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonFeedbackSoundFile");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonFeedbackSoundFile");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
+
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "SpeakLabelCheckButton");
+		g_assert (pButton != NULL);
+		gtk_widget_set_sensitive (pButton, FALSE);
+
 		return;
 	}
 
@@ -307,23 +307,23 @@ void gok_page_feedbacks_update_controls (GokFeedback* pFeedback)
 	if (pFeedback->bPermanent == TRUE)
 	{
 		/* don't allow user to edit the feedback name */
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonChangeFeedbackName");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonChangeFeedbackName");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 		
 		/* don't allow user to delete the feedback */
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonDeleteFeedback");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonDeleteFeedback");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 		
 		/* don't allow user to change the flashing on/off */
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "checkKeyFlashing");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkKeyFlashing");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pButton), pFeedback->bFlashOn);
 
 		/* don't allow user to change the sound on/off */
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "checkSoundOn");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkSoundOn");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, FALSE);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pButton), pFeedback->bSoundOn);
@@ -331,38 +331,44 @@ void gok_page_feedbacks_update_controls (GokFeedback* pFeedback)
 	else
 	{
 		/* not permanent */
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonDeleteFeedback");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonDeleteFeedback");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, TRUE);
 						
 		/* allow user to edit the feedback name */
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonChangeFeedbackName");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonChangeFeedbackName");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, TRUE);
 
 		/* allow user to change the flashing on/off */
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "checkKeyFlashing");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkKeyFlashing");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, TRUE);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pButton), pFeedback->bFlashOn);
 
 		/* allow user to change the sound on/off */
-		pButton = lookup_widget (gok_settingsdialog_get_window(), "checkSoundOn");
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkSoundOn");
 		g_assert (pButton != NULL);
 		gtk_widget_set_sensitive (pButton, TRUE);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pButton), pFeedback->bSoundOn);
+
+		/* allow user to turn the speech on/off */
+		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "SpeakLabelCheckButton");
+		g_assert (pButton != NULL);
+		gtk_widget_set_sensitive (pButton, TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pButton), pFeedback->bSpeechOn);
 	}
 	
-	pButton = lookup_widget (gok_settingsdialog_get_window(), "spinKeyFlashing");
+	pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "spinKeyFlashing");
 	g_assert (pButton != NULL);
 	gtk_widget_set_sensitive (pButton, TRUE);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pButton), pFeedback->NumberFlashes);
 
-	pButton = lookup_widget (gok_settingsdialog_get_window(), "comboSoundName");
+	pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "comboSoundName");
 	g_assert (pButton != NULL);
 	gtk_widget_set_sensitive (pButton, TRUE);
 
-	pButton = lookup_widget (gok_settingsdialog_get_window(), "entrySoundName");
+	pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entrySoundName");
 	g_assert (pButton != NULL);
 	gtk_widget_set_sensitive (pButton, TRUE);
 	m_bIgnoreSoundNameChange = TRUE;
@@ -377,7 +383,7 @@ void gok_page_feedbacks_update_controls (GokFeedback* pFeedback)
 	}
 	m_bIgnoreSoundNameChange = FALSE;
 
-	pButton = lookup_widget (gok_settingsdialog_get_window(), "buttonFeedbackSoundFile");
+	pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonFeedbackSoundFile");
 	g_assert (pButton != NULL);
 	gtk_widget_set_sensitive (pButton, TRUE);
 }
@@ -483,8 +489,7 @@ void gok_page_feedbacks_button_clicked_change_name ()
 				{
 					/* yes the name was changed */
 					g_free (m_pFeedbackCurrent->pDisplayName);
-					m_pFeedbackCurrent->pDisplayName = (gchar*)g_malloc (strlen (pNewName) + 1);
-					strcpy (m_pFeedbackCurrent->pDisplayName, pNewName);
+					m_pFeedbackCurrent->pDisplayName = g_strdup (pNewName);
 		
 					/* add the new name to the combo box list */
 					gok_page_feedbacks_fill_combo_feedback_names();
@@ -527,10 +532,8 @@ void gok_page_feedbacks_button_clicked_new()
 	}
 	
 	pFeedbackNew = gok_feedback_new();
-	pFeedbackNew->pName = (gchar*)g_malloc (strlen (bufferName) + 1);
-	strcpy (pFeedbackNew->pName, bufferName);
-	pFeedbackNew->pDisplayName = (gchar*)g_malloc (strlen (bufferDisplayName) + 1);
-	strcpy (pFeedbackNew->pDisplayName, bufferDisplayName);
+	pFeedbackNew->pName = g_strdup (bufferName);
+	pFeedbackNew->pDisplayName = g_strdup(bufferDisplayName);
 
 	/* make the new feedback the same as the current feedback */
 	if (m_pFeedbackCurrent != NULL)
@@ -577,7 +580,7 @@ void gok_page_feedbacks_fill_combo_feedback_names ()
 	m_bIgnoreChangeName = TRUE;
 	
 	/* find the combo box */
-	pComboBox = lookup_widget (gok_settingsdialog_get_window(), "comboFeedback");
+	pComboBox = glade_xml_get_widget (gok_settingsdialog_get_xml(), "comboFeedback");
 	g_assert (pComboBox != NULL);
 
 	/* create a list of feedback display names */
@@ -609,7 +612,7 @@ void gok_page_feedbacks_fill_combo_feedback_names ()
 	{
 		pFeedbackName = "";
 	}
-	pEntry = lookup_widget (gok_settingsdialog_get_window(), "entryFeedback");
+	pEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entryFeedback");
 	g_assert (pEntry != NULL);
 	gtk_entry_set_text (GTK_ENTRY(pEntry), pFeedbackName);
 	
@@ -631,7 +634,7 @@ void gok_page_feedbacks_button_clicked_delete ()
 	GokFeedback* pFeedback;
 	GokFeedback* pFeedbackDisplayed;
 	
-	pComboEntry = lookup_widget (gok_settingsdialog_get_window(), "entryFeedback");
+	pComboEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entryFeedback");
 	g_assert (pComboEntry != NULL);
 	pNameFeedback = gtk_entry_get_text (GTK_ENTRY(pComboEntry));
 
@@ -641,7 +644,7 @@ void gok_page_feedbacks_button_clicked_delete ()
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_QUESTION,
 			GTK_BUTTONS_YES_NO,
-			buffer);
+			"%s", buffer);
 	
 	gtk_window_set_title (GTK_WINDOW (pDialog), _("GOK Delete Feedback"));
 	result = gtk_dialog_run (GTK_DIALOG (pDialog));
@@ -700,7 +703,7 @@ void gok_page_feedbacks_check_keyflashing_clicked ()
 		return;
 	}
 
-	pCheckbox = lookup_widget (gok_settingsdialog_get_window(), "checkKeyFlashing");
+	pCheckbox = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkKeyFlashing");
 	g_assert (pCheckbox != NULL);
 	m_pFeedbackCurrent->bFlashOn = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(pCheckbox));
 }
@@ -719,7 +722,7 @@ void gok_page_feedbacks_spin_keyflashing_changed ()
 		return;
 	}
 
-	pSpinControl = lookup_widget (gok_settingsdialog_get_window(), "spinKeyFlashing");
+	pSpinControl = glade_xml_get_widget (gok_settingsdialog_get_xml(), "spinKeyFlashing");
 	g_assert (pSpinControl != NULL);
 	m_pFeedbackCurrent->NumberFlashes = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(pSpinControl));
 }
@@ -738,11 +741,26 @@ void gok_page_feedbacks_check_sound_clicked ()
 		return;
 	}
 
-	pCheckbox = lookup_widget (gok_settingsdialog_get_window(), "checkSoundOn");
+	pCheckbox = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkSoundOn");
 	g_assert (pCheckbox != NULL);
 	m_pFeedbackCurrent->bSoundOn = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(pCheckbox));
 }
 
+/**
+* gok_page_feedbacks_check_speech_toggled
+*
+* The checkbox has been toggled. Update the current feedback with the change.
+**/
+void gok_page_feedbacks_check_speech_toggled (GtkToggleButton *button)
+{
+	if (m_pFeedbackCurrent == NULL)
+	{
+		return;
+	}
+
+	m_pFeedbackCurrent->bSpeechOn = gtk_toggle_button_get_active (button);
+}
+
 /**
 * gok_page_feedbacks_entry_soundname_changed
 *
@@ -762,7 +780,7 @@ void gok_page_feedbacks_entry_soundname_changed ()
 		return;
 	}
 
-	pEntry = lookup_widget (gok_settingsdialog_get_window(), "entrySoundName");
+	pEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entrySoundName");
 	g_assert (pEntry != NULL);
 
 	/* is there a sound file selected? */
@@ -807,7 +825,7 @@ void gok_feedbacks_update_sound_combo()
 	GList* items = NULL;
 	GokFeedback* pFeedback;
 
-	pCombo = lookup_widget (gok_settingsdialog_get_window(), "comboSoundName");
+	pCombo = glade_xml_get_widget (gok_settingsdialog_get_xml(), "comboSoundName");
 	g_assert (pCombo != NULL);
 
 	pFeedback = gok_feedback_get_first_feedback();
@@ -885,7 +903,7 @@ void gok_page_feedbacks_get_sound_file ()
 	gok_feedbacks_update_sound_combo();
 	
 	/* display it in the entry of the combo box */
-	pEntry = lookup_widget (gok_settingsdialog_get_window(), "entrySoundName");
+	pEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entrySoundName");
 	g_assert (pEntry != NULL);
 	m_bIgnoreSoundNameChange = TRUE;
 	gtk_entry_set_text (GTK_ENTRY(pEntry), filename);
