@@ -644,7 +644,10 @@ utf8_add_to_list_from_lines (GList *list, gchar **lines, gboolean read_freqs, gb
 				gsize bytes_read, bytes_written;
 				string = g_convert (string, -1, "UTF-8", "ISO-8859-1", &bytes_read, &bytes_written, &error);
 				if (error)
-					g_warning (error->message);
+				{
+					g_warning ("%s", error->message);
+					g_error_free (error);
+				}
 			}
 			if (string)
 			{
