@@ -155,6 +155,7 @@ typedef struct _GokArgs {
 	gboolean list_accessmethods;
 	char* usb_vid_pid;
 	gdouble valuator_sensitivity;
+	gboolean non_system_mouse;
 } GokArgs;
 
 static GokArgs gok_args;
@@ -337,6 +338,15 @@ static const GOptionEntry options[] = {
 		N_("A multiplier to be applied to input device valuator events before processing"),
 		NULL
 	},
+	{
+		"non-system-mouse", 
+		'\0', 
+		0,
+		G_OPTION_ARG_NONE, 
+		&gok_args.non_system_mouse, 
+		N_("Attempt to use GOK without the system mouse"),
+		NULL
+	},
 	/* End the list */
 	{	NULL}
 };
@@ -393,6 +403,7 @@ gok_args_init (GokArgs *args)
 	args->selectactionname = NULL;
 	args->usb_vid_pid = NULL;
 	args->valuator_sensitivity = 0;
+	args->non_system_mouse = 0;
 }
 
 /* callback for gok window state events */
@@ -637,8 +648,10 @@ gok_main_open(gint argc, gchar *argv[])
 	
 	    if (ret != Bonobo_ACTIVATION_REG_SUCCESS)
 	    {
-		if (gok_args.is_login)
-		    return 1;
+		if (gok_args.is_login) {
+			g_warning ("GOK running in login mode with a failed bonobo activation");
+		    /* return 1; */
+		}
 		else {
 		    gchar *reason = NULL;
 		    if (ret == Bonobo_ACTIVATION_REG_ALREADY_ACTIVE) reason = "already active";
@@ -1228,6 +1241,7 @@ static gboolean gok_main_xevie_io (GIOChannel *source,
 				   gpointer data)
 {
 #ifdef HAVE_XEVIE
+    XEvent xevie_event;
     while (xevie_dpy && XPending (xevie_dpy)) {
       XMotionEvent *motion_event;
       gboolean has_active_key = gok_scanner_key_is_active ();
@@ -1846,6 +1860,8 @@ GtkWidget* gok_main_create_window (struct gok_window_realize_data *window_realiz
 			     "signal::destroy", on_window1_destroy, NULL,
 			     NULL);
 
+	gtk_window_set_keep_above (GTK_WINDOW (window1), TRUE); /* please! */
+	
 	g_set_application_name (_("GOK"));
 	gtk_window_set_default_icon_name ("gok");
 
@@ -1853,7 +1869,6 @@ GtkWidget* gok_main_create_window (struct gok_window_realize_data *window_realiz
 	m_OurResizeHeight = 100;
 	gtk_window_set_default_size (GTK_WINDOW (window1), m_OurResizeWidth, m_OurResizeHeight);
 
-
 	fixed1 = gtk_fixed_new ();
 	gtk_widget_ref (fixed1);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "fixed1", fixed1,
@@ -2758,7 +2773,7 @@ void gok_main_display_error (gchar* ErrorString)
 		GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_MESSAGE_ERROR,
 		GTK_BUTTONS_CLOSE,
-		buffer);
+		"%s", buffer);
 	
 	gtk_window_set_title (GTK_WINDOW (pDialog), _("GOK Fatal Error"));
 	gtk_dialog_run (GTK_DIALOG (pDialog));
@@ -2909,6 +2924,18 @@ gok_main_get_valuatorsensitivity_override (void)
 	return gok_args.valuator_sensitivity;
 }
 
+gboolean
+gok_main_get_use_corepointer (void) {
+	return !gok_args.non_system_mouse && !gok_args.inputdevicename;
+}
+
+gboolean
+gok_main_get_use_xevie (void) {
+	/* TODO: make xevie a user option
+	 */
+	return xevie_dpy && !gok_main_get_use_corepointer();
+}
+
 /**
 * gok_main_get_geometry
 *
@@ -3148,7 +3175,7 @@ gboolean
 gok_main_warn (gchar *message, gboolean always, GCallback cancelfunc, GCallback okfunc, gboolean opt_out)
 {
 
-	if (always || gok_scanner_current_state_uses_corepointer ()) 
+	if (!gok_main_get_use_corepointer() && ( always || gok_scanner_current_state_uses_corepointer() )) 
 	{
 		GtkWidget*	button;
 
@@ -3161,7 +3188,7 @@ gok_main_warn (gchar *message, gboolean always, GCallback cancelfunc, GCallback
 				GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_WARNING, 
 				GTK_BUTTONS_NONE,			
-				message);
+				"%s", message);
 			
 			button = gtk_button_new_from_stock(GTK_STOCK_HELP);
 			gtk_container_add (GTK_CONTAINER (GTK_DIALOG(_corepointer_warning)->action_area),
